# beaker-bunsen

[![PyPI - Version](https://img.shields.io/pypi/v/beaker-bunsen.svg)](https://pypi.org/project/beaker-bunsen)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/beaker-bunsen.svg)](https://pypi.org/project/beaker-bunsen)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install beaker-bunsen
```

## License

`beaker-bunsen` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
